colorscheme blue
set background=dark

" ======================= For loading latexSuite tools ======================
" this line is responsible for loading latex-suite when a .tex file is opened.
filetype plugin on

" IMPORTANT: grep will sometimes skip displaying the file name if you
" search in a singe file. This will confuse latex-suite. Set your grep
" program to alway generate a file-name.
set grepprg=grep\ -nH\ $*

" for automatic indentation specific to LaTeX.
filetype indent on
" ===========================================================================

syntax on

" Note: this ensures /usr/share/ite is searched before $VIMRUNTIME, thus
" /usr/share/ite/syntax/tex.vim is loaded instead of $VIMRUNTIME/syntax/tex.vim.
" (use ":echo &runtimepath" or ":set runtimepath" to check)
set runtimepath-=~/.vim | set runtimepath-=/usr/share/ite
set runtimepath^=~/.vim,/usr/share/ite

autocmd BufNewFile,BufRead *.tex,*.latex,*.sty,*.dtx,*.ltx,*.ctx setf tex

autocmd BufNewFile,BufRead *.tex,*.latex,*.sty,*.dtx,*.ltx,*.ctx
	\ silent! so /usr/share/ite/setup.vim

if exists('s:did_installed_CTeX_Menu')
  finish
endif

let s:did_installed_CTeX_Menu = 1

" Delete some less useful ToolBar buttons to save space
aunmenu ToolBar.Print
aunmenu ToolBar.LoadSesn
aunmenu ToolBar.SaveSesn
aunmenu ToolBar.Help
aunmenu ToolBar.FindHelp
aunmenu ToolBar.Make
aunmenu Tools.Make

"am ToolBar.Empty	:<CR>
an ToolBar.-sep100-	<Nop>

tm ToolBar.CTeX		LaTeX  --- \ll
am ToolBar.CTeX		:call CTeX_CTeX()<CR>

" Note: LaTeX-Suite might change CWD when loading a new buffer via
" xdvik's reverse search. This function sets CWD to the directory of the
" main file.
fun <SID>CTeX_chdir()
    let maindir = fnamemodify(<SID>MainFile(), ':h')
    if maindir != ""
	exec 'cd '.maindir
    endif
endfun

" returns the basename (i.e., without extension) of the main file
fun <SID>MainBase()
    return fnamemodify(<SID>MainFile(), ':r')
endfun

" returns the name of the main file
fun <SID>MainFile()
    let mainfile = glob('*.latexmain')
    if mainfile == ''
	" no .latexmain file, suppose buffer 1 the mainfile
	return expand("#1")
    else
	" strip trailing .latexmain
	return fnamemodify(mainfile, ':r')
    fi
endfun

tm ToolBar.XDvi		DVI Ԥ --- \lv
am ToolBar.XDvi		:silent! call CTeX_ViewDVI()<CR>
fun CTeX_CTeX()
    wall
    call <SID>CTeX_chdir()
    cclose
    pclose!
    let curfile = expand("%")
    exec 'edit '.<SID>MainFile()
    let &makeprg = $VTEX_CTEXCMD.' '.$VTEX_OPTS.' -interaction=nonstopmode'
    " We use the .log file instead of stdout/stderr since ctex
    " might run latex for multiple times.

    "let &shellpipe = '; /usr/share/ite/logfilter '.<SID>MainBase().'.log > '
    "	\ .<SID>MainBase().'.log.tmp; /bin/mv -f '.<SID>MainBase().'.log.tmp '
    "	\ .<SID>MainBase().'.log; /bin/cat '.<SID>MainBase().'.log > '

    " filenames in the log file is handled by ctex-0.2.0
    let &shellpipe = '; /bin/cat '.<SID>MainBase().'.log > '

    exec 'make '.<SID>MainFile()
    redraw!
    let winno = winnr()
    cwindow
    if winno != winnr()		" winnr() changed means at least one error
	cc!
    elseif curfile!=expand('%')	" no change in winnr() means no error
	exec 'edit '.curfile
    endif
endfun

fun CTeX_ViewDVI()
    call <SID>CTeX_chdir()
    let cmd = "env VTEX_CMD=\"kdvi-wrapper\" XEDITOR=vtex VTEX_NAME="
    let cmd = cmd.$VTEX_NAME." vtex ".<SID>MainBase()." &"
    let dummy = system(cmd)
endfun

tm ToolBar.Search	DVI  --- \ls
am ToolBar.Search	:silent! call CTeX_ForwardSearch()<CR>
fun CTeX_ForwardSearch()
    call <SID>CTeX_chdir()
    let cmd = "env VTEX_CMD=\"kdvi-wrapper\" XEDITOR=vtex VTEX_NAME="
    let cmd = cmd.$VTEX_NAME." vtex \"file:"
    let cmd = cmd.<SID>MainBase()."#src:".line(".")
    let cmd = cmd." ".bufname("%")."\" &"
    let dummy = system(cmd)
endfun

tm ToolBar.Quick	TeX  + DVI Ԥ --- \lb
am ToolBar.Quick	:call CTeX_QuickBuild()<CR>
fun CTeX_QuickBuild()
    call CTeX_CTeX()
    call CTeX_ViewDVI()
endfun

"am ToolBar.Empty1 :<CR>
an ToolBar.-sep101-	<Nop>

tm ToolBar.Spell	Ӣƴд
am ToolBar.Spell	:call CTeX_Spell()<CR>
fun CTeX_Spell()
    update
    so `/usr/share/ite/spell.sh %`
endfun

an ToolBar.-sep102-	<Nop>

tm ToolBar.Clean	ʱļ (ctextemp_*.*)
am ToolBar.Clean	:call CTeX_Clean()<CR>
fun CTeX_Clean()
    call <SID>CTeX_chdir()
    let dummy = strpart(input("ʱļ ctextemp_*.* (y/n) ? "), 0, 1)
    if dummy ==? "y"
	let dummy = system("sh -c 'ctex -clean 2>&1'")
    else
	let dummy = "cancelled!"
    endif
    echo dummy
endfun

" Note: LaTeX-Suite's compiler/tex.vim adds entries to efm according to
" the variable g:Tex_IgnoredWarnings whose custom definitions may be set here.
let g:Tex_IgnoredWarnings = ""
compiler tex
